"use client";

import { DESIGN_OPTIONS } from "@/config/pool-options";
import { cn } from "@/lib/utils";
import { usePoolRequestInfo } from "@/servers/data/use-pool-request-info";
import { Check, Loader2 } from "lucide-react";
import { useLocale } from "next-intl";
import Image from "next/image";
import { useState } from "react";

interface DesignOptionsProps {
	isPending: boolean;
}

export default function DesignOptions({ isPending }: DesignOptionsProps) {
	const locale = useLocale();
	const { poolRequestInfo } = usePoolRequestInfo();
	console.log("poolRequestInfo: ", poolRequestInfo);

	const [submittingId, setSubmittingId] = useState<string | null>(null);

	const handleSubmit = (e: React.FormEvent<HTMLButtonElement>) => {
		console.log("e: ", e);
		console.log("e.currentTarget.value: ", e.currentTarget.value);
		setSubmittingId(e.currentTarget.value);

	};

	return (
		<div className="flex justify-center gap-16 p-16">
			{DESIGN_OPTIONS.map(({ id, url, title_ar, title_en }: any) => {
				const is_selected = poolRequestInfo?.design_type === id;
				const is_submitting = submittingId === id && isPending;

				return (
					<div key={id} className="flex flex-col items-center gap-8">
						<Image
							src={url}
							alt={`${locale === "ar" ? title_ar : title_en} pool design`}
							width={250}
							height={250}
							style={{ objectFit: "contain" }}
							priority={true}
						/>
						<button
							type="submit"
							name="designType"
							value={id}
							onClick={handleSubmit}
							className="relative w-32 text-lg text-white py-2 bg-gradient-to-r from-[#1E1E1E] to-[rgba(30,30,30,0.7)] rounded-full transition-transform duration-300 ease-in-out hover:scale-105 hover:shadow-xl focus:outline-none focus:ring-4 focus:ring-gray-600"
							style={{ boxShadow: "#0000008f 0 5px 5px" }}
							disabled={isPending}
						>
							{is_submitting ? (
								<Loader2 className="mx-auto animate-spin" />
							) : (
								<>
									<span className={cn(is_selected && "-ml-4")}>{locale === "ar" ? title_ar : title_en}</span>
									{is_selected && (
										<Check className="absolute right-2 top-1/2 -translate-y-1/2 h-5 w-5" />
									)}
								</>
							)}
						</button>
					</div>
				);
			})}
		</div>
	);
} 